@@ -59,6 +59,7 @@ def if_files_changed(node, group_name, files)
   return if files.empty?
 
   hash_io = IO.popen(%w[xargs sha1sum], 'w+')
+  hash_io.puts(File.join(Chake.tmpdir, "#{node}.bootstrap"))
   files.sort.each { |f| hash_io.puts(f) }
   hash_io.close_write
   current_hash = hash_io.read
@@ -69,9 +70,7 @@ def if_files_changed(node, group_name, files)
 
   yield if current_hash != hash_on_disk
   FileUtils.mkdir_p(File.dirname(hash_file))
-  File.open(hash_file, 'w') do |f|
-    f.write(current_hash)
-  end
+  File.write(hash_file, current_hash)
 end
 
 def write_json_file(file, data)
@@ -111,9 +110,7 @@ Chake.nodes.each do |node|
     if !File.exist?(bootstrap_script) || File.read(bootstrap_script) != bootstrap_code
 
       # create bootstrap script
-      File.open(bootstrap_script, 'w') do |f|
-        f.write(bootstrap_code)
-      end
+      File.write(bootstrap_script, bootstrap_code)
       chmod 0o755, bootstrap_script
 
       # copy bootstrap script over
@@ -131,7 +128,7 @@ Chake.nodes.each do |node|
   end
 
   desc "upload data to #{hostname}"
-  task "upload:#{hostname}" => :upload_common do
+  task "upload:#{hostname}" => ["bootstrap:#{hostname}", :upload_common] do
     next unless node.needs_upload?
 
     encrypted = encrypted_for(hostname)
@@ -142,7 +139,7 @@ Chake.nodes.each do |node|
     rsync_excludes << '--exclude' << 'local-mode-cache/'
 
     rsync = node.rsync + ['-avp'] + ENV.fetch('CHAKE_RSYNC_OPTIONS', '').split
-    rsync_logging = Rake.application.options.silent && '--quiet' || '--verbose'
+    rsync_logging = (Rake.application.options.silent && '--quiet') || '--verbose'
 
     hash_files = Dir.glob(File.join(Chake.tmpdir, '*.sha1sum'))
     files = Dir.glob('**/*').reject { |f| File.directory?(f) } - encrypted.keys - encrypted.values - hash_files
